@@ -1,3 +1,10 @@
+# -*- coding: utf-8 -*-
+"""
+Created on Thu Nov  5 08:11:25 2020
+
+@author: Harika
+"""
+#Importi
 import pandas as pd
 import plotly
 import plotly.graph_objs as go
@@ -8,11 +15,23 @@ import numpy as np
 import matplotlib.pyplot as plt
 import seaborn as sns
 
-
+    
+    
 # Bar graph
 def bar_graph(library, dataset_path, datasource_type, values_list_column, target_column, main_title, title_x_axis, title_y_axis):
+    """
+    Parameters:
+    library : plotly/matplotlib/seaborn
+    dataset_path : Path of dataset
+    datasource_type : csv/excel/dataframe
+    values_list_column : list of independent coumns mention
+    target_column : dependent column mention
+    main_title : Main title of graph
+    title_x_axis : X_axis title of graph
+    title_y_axis : Y_axis title of graph
+    """
     if library == "plotly":
-    
+     
         if datasource_type == 'csv':
             dataset = pd.read_csv(dataset_path)
         elif datasource_type == 'excel':
@@ -50,7 +69,7 @@ def bar_graph(library, dataset_path, datasource_type, values_list_column, target
         plt.title(main_title)
         plt.xlabel(title_x_axis) 
         plt.ylabel(title_y_axis) 
-
+    
         plt.show()
         
     elif library == "seaborn":
@@ -60,7 +79,7 @@ def bar_graph(library, dataset_path, datasource_type, values_list_column, target
             dataset = pd.read_excel(dataset_path)
         elif datasource_type == 'dataframe':
             dataset = dataset_path
-        
+      
         sns.barplot(x = values_list_column, y = target_column, data = dataset) 
         plt.title(main_title)
         plt.xlabel(title_x_axis) 
@@ -74,7 +93,19 @@ def bar_graph(library, dataset_path, datasource_type, values_list_column, target
 
 #line graph
 def line_graph(library, dataset_path, datasource_type, values_list_column, target_column, main_title, title_x_axis, title_y_axis):
+    """
+    Parameters:
+    library : plotly/matplotlib/seaborn
+    dataset_path : Path of dataset
+    datasource_type : csv/excel/dataframe
+    values_list_column : list of independent coumns mention
+    target_column : dependent column mention
+    main_title : Main title of graph
+    title_x_axis : X_axis title of graph
+    title_y_axis : Y_axis title of graph
+    """
     if library == "plotly":
+        
         if datasource_type == 'csv':
             dataset = pd.read_csv(dataset_path)
         elif datasource_type == 'excel':
@@ -119,13 +150,13 @@ def line_graph(library, dataset_path, datasource_type, values_list_column, targe
             dataset = pd.read_excel(dataset_path)
         elif datasource_type == 'dataframe':
             dataset = dataset_path
-
+  
         plt.figure(figsize=(15,15))
-
+  
         plt.title(main_title)
         
         sns.lineplot(dataset[values_list_column],dataset[target_column])
-
+  
         plt.xlabel(title_x_axis)
         plt.ylabel(title_y_axis)
         plt.show()
@@ -137,7 +168,21 @@ def line_graph(library, dataset_path, datasource_type, values_list_column, targe
 
 # scatter plot
 def scatter_plot(library, dataset_path, datasource_type, values_list_column, target_column, main_title, title_x_axis, title_y_axis):
+    
+    """
+    Parameters:
+    library : plotly/matplotlib/seaborn
+    dataset_path : Path of dataset
+    datasource_type : csv/excel/dataframe
+    values_list_column : list of independent coumns mention
+    target_column : dependent column mention
+    main_title : Main title of graph
+    title_x_axis : X_axis title of graph
+    title_y_axis : Y_axis title of graph
+    """
     if library == "plotly": 
+        
+        
         if datasource_type == 'csv':
             dataset = pd.read_csv(dataset_path)
         elif datasource_type == 'excel':
@@ -158,9 +203,9 @@ def scatter_plot(library, dataset_path, datasource_type, values_list_column, tar
             xaxis_title=title_x_axis,
             yaxis_title=title_y_axis)
         plotly.offline.iplot(fig)
-    
+   
         
-    
+   
     elif library == "matplotlib":
         if datasource_type == 'csv':
             dataset = pd.read_csv(dataset_path)
@@ -169,10 +214,10 @@ def scatter_plot(library, dataset_path, datasource_type, values_list_column, tar
         elif datasource_type == 'dataframe':
             dataset = dataset_path
     
-    
+  
         x = dataset[values_list_column]
         y = dataset[target_column]
-        
+       
         
         plt.scatter(x, y, cmap='viridis', alpha=0.3)
         plt.xlabel(title_x_axis)
@@ -204,11 +249,21 @@ def scatter_plot(library, dataset_path, datasource_type, values_list_column, tar
         
     else :
         print("incorrect library used")
-
-
+      
+  
 # Pie graph
 def pie_graph(library, dataset_path, datasource_type, values_list_column, main_title):
+    """
+    Parameters:
+    library : plotly/matplotlib/seaborn
+    dataset_path : Path of dataset
+    datasource_type : csv/excel/dataframe
+    values_list_column : list of independent coumns mention
+    main_title : Main title of graph
+    """
+    
     if library=="plotly":
+        
         if datasource_type == 'csv':
             dataset = pd.read_csv(dataset_path)
         elif datasource_type == 'excel':
@@ -216,26 +271,26 @@ def pie_graph(library, dataset_path, datasource_type, values_list_column, main_t
         elif datasource_type == 'dataframe':
             dataset = dataset_path
         trace = plotly.graph_objs.Pie(values=dataset[values_list_column].value_counts().values.tolist(),
-                                        labels=dataset[values_list_column].value_counts().keys().tolist(),
-                                        hoverinfo="label+percent+name",
-                                        domain=dict(x=[0, .48]),
-                                        marker=dict(line=dict(width=2,
+                                      labels=dataset[values_list_column].value_counts().keys().tolist(),
+                                      hoverinfo="label+percent+name",
+                                      domain=dict(x=[0, .48]),
+                                      marker=dict(line=dict(width=2,
                                                             color="rgb(243,243,243)")
-                                                    ),
-                                        hole=.6
-                                        )
+                                                  ),
+                                      hole=.6
+                                      )
     
         layout = plotly.graph_objs.Layout(dict(title=values_list_column,
                                                 plot_bgcolor="rgb(243,243,243)",
                                                 paper_bgcolor="rgb(243,243,243)",
                                                 annotations=[dict(text=main_title,
-                                                                    font=dict(size=13),
-                                                                    showarrow=False,
-                                                                    x=.15, y=.5),
+                                                                  font=dict(size=13),
+                                                                  showarrow=False,
+                                                                  x=.15, y=.5),
     
                                                             ]
                                                 )
-                                            )
+                                          )
         data = [trace]
         fig = plotly.graph_objs.Figure(data=data, layout=layout)
         plotly.offline.iplot(fig)
@@ -248,7 +303,7 @@ def pie_graph(library, dataset_path, datasource_type, values_list_column, main_t
         elif datasource_type == 'dataframe':
             dataset = dataset_path
         values = dataset[values_list_column].value_counts()
-        
+       
         per=[]
         for i in values:
             perc = i/values.sum()
@@ -258,7 +313,7 @@ def pie_graph(library, dataset_path, datasource_type, values_list_column, main_t
         plt.title(main_title,fontsize=20)
         plt.pie(per,autopct='%1.1f%%')
         plt.legend(values.index,loc='best', fontsize=15)
-
+    
     
     elif library == "seaborn":
         if datasource_type == 'csv':
@@ -271,7 +326,7 @@ def pie_graph(library, dataset_path, datasource_type, values_list_column, main_t
         pie, ax = plt.subplots(figsize=[10,6])
         values = dataset[values_list_column].value_counts().values.tolist()
         labels = dataset[values_list_column].value_counts().keys()
-
+  
         plt.pie(x=values, autopct="%.1f%%", labels=labels, pctdistance=0.5)
         plt.title(main_title, fontsize=14);
         
@@ -283,7 +338,19 @@ def pie_graph(library, dataset_path, datasource_type, values_list_column, main_t
 
 #Box Plot
 def box_plot(library, dataset_path, datasource_type, values_list_column, target_column, main_title, title_x_axis, title_y_axis):
+    """
+    Parameters:
+    library : plotly/matplotlib/seaborn
+    dataset_path : Path of dataset
+    datasource_type : csv/excel/dataframe
+    values_list_column : list of independent coumns mention
+    target_column : dependent column mention
+    main_title : Main title of graph
+    title_x_axis : X_axis title of graph
+    title_y_axis : Y_axis title of graph
+    """
     if library == "plotly": 
+        
         if datasource_type == 'csv':
             dataset = pd.read_csv(dataset_path)
         elif datasource_type == 'excel':
@@ -293,8 +360,8 @@ def box_plot(library, dataset_path, datasource_type, values_list_column, target_
     
         fig = px.box(dataset, x=values_list_column, y=target_column)
         fig.show()
-                    
-        
+                      
+          
     elif library == "matplotlib":
         if datasource_type == 'csv':
             dataset = pd.read_csv(dataset_path)
@@ -307,44 +374,57 @@ def box_plot(library, dataset_path, datasource_type, values_list_column, target_
         dataset.boxplot(by = values_list_column, column = target_column, grid = False) 
         
         plt.title(main_title)
-        
+       
         plt.xlabel(title_x_axis)
         plt.ylabel(title_y_axis)
         plt.show()
-        
-        
-        
+          
+          
+          
     elif library == "seaborn":
-            if datasource_type == 'csv':
+    
+        if datasource_type == 'csv':
             dataset = pd.read_csv(dataset_path)
-            elif datasource_type == 'excel':
+        elif datasource_type == 'excel':
             dataset = pd.read_excel(dataset_path)
-            elif datasource_type == 'dataframe':
+        elif datasource_type == 'dataframe':
             dataset = dataset_path
-        
-        
-            plt.figure(figsize=(14,6))
-        
+    
+ 
+        plt.figure(figsize=(14,6))
+    
         # Add title
-            plt.title(main_title)
-            ax= sns.boxplot(x=values_list_column,y=target_column,data=dataset)
-            
-            # Add label for horizontal axis
-            plt.xlabel(title_x_axis)
-            plt.ylabel(title_y_axis)
-            plt.show()
-        
-        
+        plt.title(main_title)
+        ax= sns.boxplot(x=values_list_column,y=target_column,data=dataset)
+       
+        # Add label for horizontal axis
+        plt.xlabel(title_x_axis)
+        plt.ylabel(title_y_axis)
+        plt.show()
+          
+          
     else:
-            print("incorrect library used")
-
-
-
-
+        print("incorrect library used")
+      
+      
+  
+  
 #Violin Plot
 def violin_plot(library, dataset_path, datasource_type, values_list_column, target_column, main_title, title_x_axis, title_y_axis):
-
+    """
+    Parameters:
+    library : plotly/matplotlib/seaborn
+    dataset_path : Path of dataset
+    datasource_type : csv/excel/dataframe
+    values_list_column : list of independent coumns mention
+    target_column : dependent column mention
+    main_title : Main title of graph
+    title_x_axis : X_axis title of graph
+    title_y_axis : Y_axis title of graph
+    """
+  
     if library == "matplotlib":
+        
         if datasource_type == 'csv':
             dataset = pd.read_csv(dataset_path)
         elif datasource_type == 'excel':
@@ -363,13 +443,13 @@ def violin_plot(library, dataset_path, datasource_type, values_list_column, targ
         # Create the boxplot
         bp = ax.violinplot(data_to_plot)
         plt.title(main_title)
-            
+         
         plt.xlabel(title_x_axis)
         plt.ylabel(title_y_axis)
         plt.show()
         plt.show() 
-            
-            
+          
+         
         
     elif library == "seaborn":
         if datasource_type == 'csv':
@@ -381,11 +461,11 @@ def violin_plot(library, dataset_path, datasource_type, values_list_column, targ
             
         sns.violinplot(x=values_list_column, y=target_column, data=dataset, palette="Pastel1")
         plt.title(main_title)
-        
+       
         plt.xlabel(title_x_axis)
         plt.ylabel(title_y_axis)
         plt.show()
-        
+      
         
     elif library == "plotly":
         if datasource_type == 'csv':
@@ -403,33 +483,44 @@ def violin_plot(library, dataset_path, datasource_type, values_list_column, targ
     
     else:
         print("incorrect library used")
-                    
-            
-                    
-
+                  
+          
+                  
+  
 # Function for correlation  matrix
 def correlation_matrix(library, dataset_path, datasource_type, main_title, scale_title):
+    """
+    Parameters:
+    library : plotly/matplotlib/seaborn
+    dataset_path : Path of dataset
+    datasource_type : csv/excel/dataframe
+    main_title : Main title of graph
+    scale_title: Title of the scale mention
+    """
+    
     if library=="plotly":
+        
+      
         if datasource_type == 'csv':
             dataset = pd.read_csv(dataset_path)
         elif datasource_type == 'excel':
             dataset = pd.read_excel(dataset_path)
         elif datasource_type == 'dataframe':
             dataset = dataset_path
-
+  
         correlation = dataset.corr()
         matrix_cols = correlation.columns.tolist()
         corr_array = np.array(correlation)
-
+  
         trace = plotly.graph_objs.Heatmap(z=corr_array,
-                                            x=matrix_cols,
-                                            y=matrix_cols,
-                                            colorscale="Viridis",
-                                            colorbar=dict(title=scale_title,
+                                          x=matrix_cols,
+                                          y=matrix_cols,
+                                          colorscale="Viridis",
+                                          colorbar=dict(title=scale_title,
                                                         titleside="right"
                                                         ),
-                                            )
-
+                                          )
+  
         layout = plotly.graph_objs.Layout(dict(title=main_title,
                                                 autosize=False,
                                                 height=720,
@@ -440,13 +531,13 @@ def correlation_matrix(library, dataset_path, datasource_type, main_title, scale
                                                 yaxis=dict(tickfont=dict(size=9)),
                                                 xaxis=dict(tickfont=dict(size=9))
                                                 )
-                                            )
-
+                                          )
+  
         data = [trace]
         fig = plotly.graph_objs.Figure(data=data, layout=layout)
         plotly.offline.iplot(fig)
         
-
+  
     elif library=="matplotlib":
         if datasource_type == 'csv':
             dataset = pd.read_csv(dataset_path)
@@ -454,9 +545,9 @@ def correlation_matrix(library, dataset_path, datasource_type, main_title, scale
             dataset = pd.read_excel(dataset_path)
         elif datasource_type == 'dataframe':
             dataset = dataset_path
-
+  
         corr = dataset.corr()
-
+  
         from matplotlib import rc
         rc('font',**{'family':'sans-serif','sans-serif':['Arial']})
         plt.suptitle(main_title, fontsize=16)
@@ -476,11 +567,11 @@ def correlation_matrix(library, dataset_path, datasource_type, main_title, scale
             dataset = dataset_path
             
         corr = dataset.corr()   
-            
+          
         plt.figure(figsize=(16, 6))
-
+  
         heatmap = sns.heatmap(corr, vmin=-1, vmax=1, annot=True)
-
+  
         heatmap.set_title(main_title, fontdict={'fontsize':12}, pad=12);
         plt.show()
         
@@ -492,7 +583,17 @@ def correlation_matrix(library, dataset_path, datasource_type, main_title, scale
 
 #Distribution Plot
 def dist_plot(library, dataset_path, datasource_type, values_list_column, main_title):
+    """
+    Parameters:
+    library : plotly/matplotlib/seaborn
+    dataset_path : Path of dataset
+    datasource_type : csv/excel/dataframe
+    values_list_column : list of independent coumns mention
+    main_title : Main title of graph
+    """
+    
     if library == "seaborn":
+        
         if datasource_type == 'csv':
             dataset = pd.read_csv(dataset_path)
         elif datasource_type == 'excel':
@@ -503,8 +604,9 @@ def dist_plot(library, dataset_path, datasource_type, values_list_column, main_t
         sns.distplot(dataset[values_list_column], bins=30)
         plt.title(main_title)
         plt.show()
-        
+      
     elif library == "matplotlib":
+        
         if datasource_type == 'csv':
             dataset = pd.read_csv(dataset_path)
         elif datasource_type == 'excel':
@@ -515,8 +617,9 @@ def dist_plot(library, dataset_path, datasource_type, values_list_column, main_t
         dataset[values_list_column].hist(bins=15, figsize=(11,11))
         plt.title(main_title)
         plt.show()
-        
+      
     elif library == "plotly":
+        
         if datasource_type == 'csv':
             dataset = pd.read_csv(dataset_path)
         elif datasource_type == 'excel':
@@ -533,13 +636,19 @@ def dist_plot(library, dataset_path, datasource_type, values_list_column, main_t
 
     else:
         print("incorrect library used")
-        
-        
-        
+          
+      
+      
 
-    
+   
 #Single lib plots      
 def histogram(dataset_path, datasource_type):
+    """
+    Parameters:
+    dataset_path : Path of dataset
+    datasource_type : csv/excel/dataframe
+    """
+    
     if datasource_type == 'csv':
         dataset = pd.read_csv(dataset_path)
     elif datasource_type == 'excel':
@@ -548,12 +657,17 @@ def histogram(dataset_path, datasource_type):
         dataset = dataset_path
     dataset.hist(bins=15, figsize=(5,5))
     plt.show()
-
-
-
+  
+  
+  
 #To Check the missingvalues using heatmap
 def missingvalues(dataset_path, datasource_type):
-    
+    """
+    Parameters:
+    dataset_path : Path of dataset
+    datasource_type : csv/excel/dataframe
+    """
+  
     if datasource_type == 'csv':
         dataset = pd.read_csv(dataset_path)
     elif datasource_type == 'excel':
@@ -568,7 +682,14 @@ def missingvalues(dataset_path, datasource_type):
 
 # to check count 
 def count_plot(dataset_path, datasource_type, values_list_column, main_title):
-    
+    """
+    Parameters:
+    dataset_path : Path of dataset
+    datasource_type : csv/excel/dataframe
+    values_list_column : list of independent coumns mention
+    main_title : Main title of graph
+    """
+ 
     if datasource_type == 'csv':
         dataset = pd.read_csv(dataset_path)
     elif datasource_type == 'excel':
@@ -581,7 +702,7 @@ def count_plot(dataset_path, datasource_type, values_list_column, main_title):
     plt.show()
     # Show the plot 
     plt.show() 
- 
+   
                 
 
    
\ No newline at end of file
